#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

"""

==========
aeresrh.py
==========

DESCRIPTION
===========

extract information from aeresrh.xls

.. option:: --ifile <file>

      file to read

.. only:: man

    Figure is visible on PDF and HTML documents only.

    .. only:: html or latex

       .. graphviz::

             digraph aeresrh {
     rh [shape=diamond,
         fontname=Courier,
 label='{ifile}'

           aeresrh [shape=box,
             fontname=Courier,
               color=blue,
                 URL="http://forge.ipsl.jussieu.fr/pulsation/browser//branches/aeresrh/scripts/aeresrh.py",
           label="${PROJECT}/aeres/scripts/aeresrh.py"];
             }

SEE ALSO
========

https://secure.simplistix.co.uk/svn/xlrd/trunk/xlrd/doc/xlrd.html

EXAMPLES
========

 aeresrh.py -ifile ${PROJECT}/data/aeresrh.xls

TODO
====

test with real file (encoding, francais, etc)

missing values

remove hard coded number of columns for surname, firstname, ...

coding rules (pylint)

EVOLUTIONS
==========

$Id$

$URL$

- fplod 20120405
 
  * gestion des temps (arrive, dpart) (to be cont.)
  * creation draft
    thanks to http://www.portailsig.org/content/python-lire-et-ecrire-des-fichiers-microsoft-excel-application-quantum-gis
    and http://scienceoss.com/read-excel-files-from-python/
"""

import sys
import os
from os.path import dirname, basename
import glob
from optparse import OptionParser

import datetime

try:
    import xlrd
except ImportError:
    print("Failed to import xlrd from any known place")
    sys.exit(1)

def get_option_parser ():
    """parse CLI arguments

           :returns: parser
          :rtype: :class:`optparse.OptionParser`
    """

    parser = OptionParser('%prog [--verbose ] [--ifile file')
    parser.add_option ('-V', '--verbose',
        help='produce verbose output',
        action='store_true',
        default=False,
        dest='is_verbose')
    parser.add_option ('-i', '--ifile',
        help='file to be read',
	type='string',
        dest='ifile',
	default=None,
        action='store')

    return parser

def readrh(ifile, is_verbose):

    """
    read ifile

    return ++
    """

    if is_verbose == True:
        print('iii : read %s' % ifile)

    # ouverture du fichier Excel
    wb = xlrd.open_workbook(ifile)

    # feuilles dans le classeur
    if is_verbose == True:
        print('sheets name %s' % ( wb.sheet_names()))

    # lecture des donnes dans la premire feuille
    sh = wb.sheet_by_index(0)

    #
    if is_verbose == True:
        for rownum in range(sh.nrows):
            print('values of in row %d : %s' % (rownum, sh.row_values(rownum)))

    if is_verbose == True:
        for colnum in range(sh.ncols):
            print('values of in col %d : %s' % (colnum, sh.col_values(colnum)))

    colsurname = 1
    colfirstname = 2
    colarrival = 13
    coldeparture = 14
    colpubli = 16 

    datemode = 0 

    surname = sh.col_values(colsurname)
    # remove the first element because it is the title
    surname[0] = ''
    surname = filter(lambda surname: surname != '', surname)

    if is_verbose == True:
       print(' nb surname %d' % len(surname))
       print(' surname %s' % surname)

    firstname = sh.col_values(colfirstname)
    # remove the first element because it is the title
    firstname[0] = ''
    firstname = filter(lambda firstname: firstname != '', firstname)

    if is_verbose == True:
       print(' nb firstname %d' % len(firstname))
       print(' firstname %s' % firstname)

    temp = sh.col_values(colarrival)
    # remove the first element because it is the title
    temp[0] = ''
    temp = filter(lambda temp: temp != '', temp)
    # transform to datetime
    arrival = []
    for rownum in range(len(temp)):
        #++ pb sh.datemodearrival = datetime.datetime(*xlrd.xldate_as_tuple(temp[rownum],sh.datemode))
        arrival.append(datetime.datetime(*xlrd.xldate_as_tuple(temp[rownum],datemode)))

    if is_verbose == True:
       print(' nb arrival %d' % len(arrival))
       print(' arrival %s' % arrival)

    temp = sh.col_values(coldeparture)
    # remove the first element because it is the title
    temp[0] = ''
    temp = filter(lambda temp: temp != '', temp)
    # transform to datetime
    departure = []
    for rownum in range(len(temp)):
        #++ pb sh.datemodedeparture = datetime.datetime(*xlrd.xldate_as_tuple(temp[rownum],sh.datemode))
        departure.append(datetime.datetime(*xlrd.xldate_as_tuple(temp[rownum],datemode)))

    if is_verbose == True:
       print(' nb departure %d' % len(departure))
       print(' departure %s' % departure)

    publi = sh.col_values(colpubli)
    # remove the first element because it is the title
    publi[0] = ''
    publi = filter(lambda publi: publi != '', publi)

    if is_verbose == True:
       print(' nb publi %d' % len(publi))
       print(' publi %s' % publi)

    return surname, firstname, arrival, departure, publi

def aeresrh():
    """main
        """
    try:
        parser = get_option_parser ()
        (fromcli, args) = parser.parse_args()
    except IOError, msg:
        parser.error(str(msg))

    is_verbose = fromcli.is_verbose
    ifile = fromcli.ifile
    if fromcli.is_verbose == True:
       print ('ifile : %s' % (ifile))

    surname, firstname, arrival, departure,publi = readrh(ifile, is_verbose)
    print (' surname %s' % (surname))

# Run main, if called from the command line
if __name__ == '__main__':
    aeresrh()

